%%==============================================================================
%% Type definition for the Workzone Path data structure
%%==============================================================================
-module(bec_wz_path_t).

%%==============================================================================
%% Exports
%%==============================================================================
-export([ from_map/1, to_map/1]).

-include("bitbucket.hrl").

%%==============================================================================
%% Types
%%==============================================================================
-type path() :: #{ path   := binary()
                 , users  := [bec_user_t:name()]
                 , groups := [bec_group_t:name()]
                 }.

%%==============================================================================
%% Export Types
%%==============================================================================
-export_type([ path/0
             ]).

%%==============================================================================
%% API
%%==============================================================================
-spec from_map(map()) -> path().
from_map(Map) ->
  #{ <<"filePathPattern">> := Path
   , <<"users">>           := Users
   , <<"groups">>          := Groups
   } = Map,
  #{ path   => Path
   , users  => lists:sort([bec_wz_user_t:from_map(U) || U <- Users])
   , groups => lists:sort(Groups)
   }.

-spec to_map(path()) -> map().
to_map(#{ path   := Path
        , users  := Users
        , groups := Groups
        }) ->
  #{ <<"filePathPattern">> => Path
   , <<"users">>           => [bec_wz_user_t:to_map(U) || U <- Users]
   , <<"groups">>          => Groups
   }.
